@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,8 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#[cfg(feature = "admin-service-client")]
+pub mod client;
 pub mod error;
 pub mod messages;
 #[cfg(feature = "rest-api")]
 pub mod rest_api;
 pub mod service;
+pub mod store;
