@@ -288,6 +288,8 @@ impl AdminService {
                         routing_members.push(routing::CircuitNode::new(
                             member.node_id().to_string(),
                             node.endpoints().to_vec(),
+                            #[cfg(feature = "challenge-authorization")]
+                            None,
                         ))
                     } else {
                         error!("Missing node information for {}", member.node_id());
@@ -332,6 +334,8 @@ impl AdminService {
                             .iter()
                             .map(|node| node.node_id().to_string())
                             .collect(),
+                        #[cfg(feature = "challenge-authorization")]
+                        routing::AuthorizationType::Trust,
                     ),
                     routing_members,
                 )
@@ -738,7 +742,6 @@ impl Service for AdminService {
                 );
                 Ok(())
             }
-            #[cfg(feature = "proposal-removal")]
             AdminMessage_Type::REMOVED_PROPOSAL => {
                 let removed_proposal = admin_message.get_removed_proposal();
                 let circuit_id = removed_proposal.get_circuit_id();
@@ -752,10 +755,6 @@ impl Service for AdminService {
             AdminMessage_Type::UNSET => Err(ServiceError::InvalidMessageFormat(Box::new(
                 AdminError::MessageTypeUnset,
             ))),
-            #[cfg(not(feature = "proposal-removal"))]
-            _ => Err(ServiceError::InvalidMessageFormat(Box::new(
-                AdminError::MessageTypeUnhandled,
-            ))),
         }
     }
 
@@ -944,8 +943,12 @@ mod tests {
             ),
         ]);
 
-        let authorization_manager = AuthorizationManager::new("test-node".into())
-            .expect("Unable to create authorization pool");
+        let authorization_manager = AuthorizationManager::new(
+            "test-node".into(),
+            #[cfg(feature = "challenge-authorization")]
+            vec![],
+        )
+        .expect("Unable to create authorization pool");
         let mut authorizers = Authorizers::new();
         authorizers.add_authorizer("inproc", inproc_authorizer);
         authorizers.add_authorizer("", authorization_manager.authorization_connector());
