@@ -187,6 +187,8 @@ mod tests {
     use std::collections::VecDeque;
     use std::sync::{Arc, Mutex};
 
+    #[cfg(feature = "challenge-authorization")]
+    use crate::circuit::routing::AuthorizationType;
     use crate::circuit::routing::{
         memory::RoutingTable, Circuit, CircuitNode, RoutingTableWriter, Service,
     };
@@ -206,8 +208,18 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_1234 = CircuitNode::new("1234".to_string(), vec!["123.0.0.1:0".to_string()]);
-        let node_5678 = CircuitNode::new("5678".to_string(), vec!["123.0.0.1:1".to_string()]);
+        let node_1234 = CircuitNode::new(
+            "1234".to_string(),
+            vec!["123.0.0.1:0".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
+        let node_5678 = CircuitNode::new(
+            "5678".to_string(),
+            vec!["123.0.0.1:1".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
 
         let service_abc = Service::new(
             "abc".to_string(),
@@ -227,6 +239,8 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Trust,
         );
 
         writer
@@ -286,8 +300,18 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_1234 = CircuitNode::new("1234".to_string(), vec!["123.0.0.1:0".to_string()]);
-        let node_5678 = CircuitNode::new("5678".to_string(), vec!["123.0.0.1:1".to_string()]);
+        let node_1234 = CircuitNode::new(
+            "1234".to_string(),
+            vec!["123.0.0.1:0".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
+        let node_5678 = CircuitNode::new(
+            "5678".to_string(),
+            vec!["123.0.0.1:1".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
 
         let service_abc = Service::new(
             "abc".to_string(),
@@ -307,6 +331,8 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Trust,
         );
 
         writer
@@ -366,8 +392,18 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_1234 = CircuitNode::new("1234".to_string(), vec!["123.0.0.1:0".to_string()]);
-        let node_5678 = CircuitNode::new("5678".to_string(), vec!["123.0.0.1:1".to_string()]);
+        let node_1234 = CircuitNode::new(
+            "1234".to_string(),
+            vec!["123.0.0.1:0".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
+        let node_5678 = CircuitNode::new(
+            "5678".to_string(),
+            vec!["123.0.0.1:1".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
 
         let service_abc = Service::new(
             "abc".to_string(),
@@ -387,6 +423,8 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Trust,
         );
 
         writer
