@@ -112,6 +112,8 @@ mod tests {
     use std::collections::VecDeque;
     use std::sync::{Arc, Mutex};
 
+    #[cfg(feature = "challenge-authorization")]
+    use crate::circuit::routing::AuthorizationType;
     use crate::circuit::routing::{
         memory::RoutingTable, Circuit, CircuitNode, RoutingTableWriter, Service,
     };
@@ -131,8 +133,18 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()]);
-        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()]);
+        let node_123 = CircuitNode::new(
+            "123".to_string(),
+            vec!["123.0.0.1:0".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
+        let node_345 = CircuitNode::new(
+            "345".to_string(),
+            vec!["123.0.0.1:1".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
 
         let mut service_abc = Service::new(
             "abc".to_string(),
@@ -152,6 +164,8 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Trust,
         );
 
         writer
@@ -223,8 +237,18 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()]);
-        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()]);
+        let node_123 = CircuitNode::new(
+            "123".to_string(),
+            vec!["123.0.0.1:0".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
+        let node_345 = CircuitNode::new(
+            "345".to_string(),
+            vec!["123.0.0.1:1".to_string()],
+            #[cfg(feature = "challenge-authorization")]
+            None,
+        );
 
         let mut service_abc = Service::new(
             "abc".to_string(),
@@ -244,6 +268,8 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Trust,
         );
 
         writer
