@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,6 +17,10 @@
 mod bi_hash_map;
 mod error;
 mod ref_map;
+#[cfg(feature = "oauth")]
+mod ttl_map;
 
 pub(crate) use bi_hash_map::BiHashMap;
 pub(crate) use ref_map::RefMap;
+#[cfg(feature = "oauth")]
+pub(crate) use ttl_map::TtlMap;
