@@ -26,6 +26,7 @@ use crate::protos::network::{NetworkMessage, NetworkMessageType};
 use crate::protos::prelude::*;
 
 use crate::network::auth::{
+    state_machine::trust_v0::{TrustV0AuthorizationAction, TrustV0AuthorizationState},
     AuthorizationAction, AuthorizationActionError, AuthorizationManagerStateMachine,
     AuthorizationState,
 };
@@ -61,7 +62,7 @@ impl Handler for AuthorizedHandler {
         );
         match self.auth_manager.next_state(
             context.source_connection_id(),
-            AuthorizationAction::RemoteAuthorizing,
+            AuthorizationAction::TrustV0(TrustV0AuthorizationAction::RemoteAuthorizing),
         ) {
             Err(err) => {
                 warn!(
@@ -125,7 +126,7 @@ impl Handler for ConnectRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationState::Connecting) => {
+            Ok(AuthorizationState::TrustV0(TrustV0AuthorizationState::Connecting)) => {
                 debug!("Beginning handshake for {}", context.source_connection_id(),);
                 // Send a connect request of our own
 
@@ -262,7 +263,9 @@ impl Handler for TrustRequestHandler {
         let trust_request = TrustRequest::from_proto(msg)?;
         match self.auth_manager.next_state(
             context.source_connection_id(),
-            AuthorizationAction::TrustIdentifyingV0(trust_request.identity),
+            AuthorizationAction::TrustV0(TrustV0AuthorizationAction::TrustIdentifyingV0(
+                trust_request.identity,
+            )),
         ) {
             Err(err) => {
                 warn!(
@@ -271,8 +274,10 @@ impl Handler for TrustRequestHandler {
                     err
                 );
             }
-            Ok(AuthorizationState::RemoteIdentified(identity))
-            | Ok(AuthorizationState::Authorized(identity)) => {
+            Ok(AuthorizationState::TrustV0(TrustV0AuthorizationState::RemoteIdentified(
+                identity,
+            )))
+            | Ok(AuthorizationState::AuthComplete(Some(identity))) => {
                 debug!(
                     "Sending Authorized message to connection {} after receiving identity {}",
                     context.source_connection_id(),
@@ -321,8 +326,13 @@ mod tests {
         let auth_mgr = AuthorizationManagerStateMachine::default();
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
-        let dispatcher =
-            create_authorization_dispatcher("mock_identity".into(), auth_mgr, dispatch_sender);
+        let dispatcher = create_authorization_dispatcher(
+            "mock_identity".into(),
+            #[cfg(feature = "challenge-authorization")]
+            vec![],
+            auth_mgr,
+            dispatch_sender,
+        );
 
         let connection_id = "test_connection".to_string();
         let mut msg = authorization::ConnectRequest::new();
@@ -380,8 +390,13 @@ mod tests {
         let auth_mgr = AuthorizationManagerStateMachine::default();
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
-        let dispatcher =
-            create_authorization_dispatcher("mock_identity".into(), auth_mgr, dispatch_sender);
+        let dispatcher = create_authorization_dispatcher(
+            "mock_identity".into(),
+            #[cfg(feature = "challenge-authorization")]
+            vec![],
+            auth_mgr,
+            dispatch_sender,
+        );
         let connection_id = "test_connection".to_string();
         let mut msg = authorization::ConnectResponse::new();
         msg.set_accepted_authorization_types(
@@ -424,8 +439,13 @@ mod tests {
         let auth_mgr = AuthorizationManagerStateMachine::default();
         let mock_sender = MockSender::new();
         let dispatch_sender = mock_sender.clone();
-        let dispatcher =
-            create_authorization_dispatcher("mock_identity".into(), auth_mgr, dispatch_sender);
+        let dispatcher = create_authorization_dispatcher(
+            "mock_identity".into(),
+            #[cfg(feature = "challenge-authorization")]
+            vec![],
+            auth_mgr,
+            dispatch_sender,
+        );
         let connection_id = "test_connection".to_string();
         // Begin the connection process, otherwise, the response will fail
         let mut msg = authorization::ConnectRequest::new();
