@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,21 +22,30 @@
 //! [`PeerInterconnectBuilder`]: struct.PeerInterconnectBuilder.html
 //! [`ShutdownSignaler`]: struct.ShutdownSignaler.html
 
-use std::collections::HashMap;
+use std::collections::{HashMap, VecDeque};
 use std::sync::mpsc::{channel, Receiver, Sender};
 use std::thread;
+use std::time::Instant;
 
 use protobuf::Message;
 
+use crate::error::InternalError;
 use crate::network::dispatch::DispatchMessageSender;
 use crate::protos::network::{NetworkMessage, NetworkMessageType};
+use crate::threading::lifecycle::ShutdownHandle;
+use crate::threading::pacemaker;
 use crate::transport::matrix::{
-    ConnectionMatrixReceiver, ConnectionMatrixRecvError, ConnectionMatrixSender,
+    ConnectionMatrixEnvelope, ConnectionMatrixReceiver, ConnectionMatrixRecvError,
+    ConnectionMatrixSender,
 };
 
 use super::connector::{PeerLookup, PeerLookupProvider};
 use super::error::PeerInterconnectError;
 
+const DEFAULT_PENDING_QUEUE_SIZE: usize = 100;
+const DEFAULT_TIME_BETWEEN_ATTEMPTS: u64 = 10; // 10 seconds
+const DEFAULT_INITIAL_ATTEMPTS: usize = 3; // 3 attempts
+
 /// Message to send to the network message sender with the recipient and payload
 #[derive(Clone, Debug, PartialEq)]
 pub(crate) enum SendRequest {
@@ -90,7 +99,9 @@ pub struct PeerInterconnect {
     dispatched_sender: Sender<SendRequest>,
     recv_join_handle: thread::JoinHandle<()>,
     send_join_handle: thread::JoinHandle<()>,
-    shutdown_signaler: ShutdownSignaler,
+    recv_pending_join_handle: thread::JoinHandle<()>,
+    pending_shutdown_sender: Sender<RetryIncoming>,
+    pacemaker_shutdown_signaler: pacemaker::ShutdownSignaler,
 }
 
 impl PeerInterconnect {
@@ -98,25 +109,43 @@ impl PeerInterconnect {
     pub fn new_network_sender(&self) -> NetworkMessageSender {
         NetworkMessageSender::new(self.dispatched_sender.clone())
     }
+}
 
-    /// Returns a `ShutdownHandle` that can be used to shutdown `PeerInterconnect`
-    pub fn shutdown_handle(&self) -> ShutdownHandle {
-        ShutdownHandle::from(self.shutdown_signaler.clone())
+impl ShutdownHandle for PeerInterconnect {
+    /// Instructs the component to begin shutting down.
+    ///
+    /// For components with threads, this should break out of any loops and ready the threads for
+    /// being joined.
+    fn signal_shutdown(&mut self) {
+        self.pacemaker_shutdown_signaler.shutdown();
+
+        if self
+            .pending_shutdown_sender
+            .send(RetryIncoming::Shutdown)
+            .is_err()
+        {
+            warn!(
+                "Cannot signal Peer Interconnect pending receive loop to shutdown, \
+                already stopped"
+            );
+        };
+
+        if self.dispatched_sender.send(SendRequest::Shutdown).is_err() {
+            warn!("Peer Interconnect is no longer running");
+        }
     }
 
-    /// Returns a `ShutdownSignaler` for this `PeerManager`
-    pub fn shutdown_signaler(&self) -> ShutdownSignaler {
-        self.shutdown_signaler.clone()
-    }
-
-    /// Waits for the send and receive thread to shutdown
-    pub fn await_shutdown(self) {
+    /// Waits until the the component has completely shutdown.
+    ///
+    /// For components with threads, the threads should be joined during the call to
+    /// `wait_for_shutdown`.
+    fn wait_for_shutdown(self) -> Result<(), InternalError> {
         debug!("Shutting down peer interconnect receiver...");
         if let Err(err) = self.send_join_handle.join() {
-            error!(
+            return Err(InternalError::with_message(format!(
                 "Peer interconnect send thread did not shutdown correctly: {:?}",
                 err
-            );
+            )));
         };
         debug!("Shutting down peer interconnect receiver (complete)");
 
@@ -128,13 +157,15 @@ impl PeerInterconnect {
             );
         }
         debug!("Shutting down peer interconnect sender (complete)");
-    }
 
-    /// Calls shutdown on the shutdown handle and then waits for the `PeerInterconnect` threads to
-    /// finish
-    pub fn shutdown_and_wait(self) {
-        self.shutdown_signaler().shutdown();
-        self.await_shutdown();
+        if let Err(err) = self.recv_pending_join_handle.join() {
+            error!(
+                "Peer interconnect pending recv thread did not shutdown correctly: {:?}",
+                err
+            );
+        }
+
+        Ok(())
     }
 }
 
@@ -225,6 +256,7 @@ where
     /// shutdown message threads.
     pub fn build(&mut self) -> Result<PeerInterconnect, PeerInterconnectError> {
         let (dispatched_sender, dispatched_receiver) = channel();
+        let (pending_incoming_sender, pending_incoming_receiver) = channel();
         let peer_lookup_provider = self.peer_lookup_provider.take().ok_or_else(|| {
             PeerInterconnectError::StartUpError("Peer lookup provider missing".to_string())
         })?;
@@ -239,6 +271,9 @@ where
         })?;
 
         let recv_peer_lookup = peer_lookup_provider.peer_lookup();
+        let pending_network_dispatcher_sender = network_dispatcher_sender.clone();
+        let pacemaker_pending_incoming_sender = pending_incoming_sender.clone();
+        let pending_shutdown_sender = pending_incoming_sender.clone();
         debug!("Starting peer interconnect receiver");
         let recv_join_handle = thread::Builder::new()
             .name("PeerInterconnect Receiver".into())
@@ -246,9 +281,10 @@ where
                 if let Err(err) = run_recv_loop(
                     &*recv_peer_lookup,
                     message_receiver,
-                    network_dispatcher_sender,
+                    network_dispatcher_sender.clone(),
+                    pending_incoming_sender,
                 ) {
-                    error!("Shutting down peer interconnect recevier: {}", err);
+                    error!("Shutting down peer interconnect receiver: {}", err);
                 }
             })
             .map_err(|err| {
@@ -258,6 +294,25 @@ where
                 ))
             })?;
 
+        let pending_recv_peer_lookup = peer_lookup_provider.peer_lookup();
+        let recv_pending_join_handle = thread::Builder::new()
+            .name("PeerInterconnect Pending Recv".into())
+            .spawn(move || {
+                if let Err(err) = run_pending_recv_loop(
+                    &*pending_recv_peer_lookup,
+                    pending_incoming_receiver,
+                    pending_network_dispatcher_sender,
+                ) {
+                    error!("Shutting down peer interconnect pending receiver: {}", err);
+                }
+            })
+            .map_err(|err| {
+                PeerInterconnectError::StartUpError(format!(
+                    "Unable to start PeerInterconnect pending receiver thread {}",
+                    err
+                ))
+            })?;
+
         let send_peer_lookup = peer_lookup_provider.peer_lookup();
         let message_sender = self
             .message_sender
@@ -280,13 +335,23 @@ where
                 ))
             })?;
 
+        // set up pacemaker that will notifiy the pending thread to retry the received messages
+        let pacemaker = pacemaker::Pacemaker::builder()
+            .with_interval(DEFAULT_TIME_BETWEEN_ATTEMPTS)
+            .with_sender(pacemaker_pending_incoming_sender)
+            .with_message_factory(|| RetryIncoming::Retry)
+            .start()
+            .map_err(|err| PeerInterconnectError::StartUpError(err.to_string()))?;
+
+        let pacemaker_shutdown_signaler = pacemaker.shutdown_signaler();
+
         Ok(PeerInterconnect {
-            dispatched_sender: dispatched_sender.clone(),
+            dispatched_sender,
             recv_join_handle,
             send_join_handle,
-            shutdown_signaler: ShutdownSignaler {
-                sender: dispatched_sender,
-            },
+            recv_pending_join_handle,
+            pending_shutdown_sender,
+            pacemaker_shutdown_signaler,
         })
     }
 }
@@ -295,6 +360,7 @@ fn run_recv_loop<R>(
     peer_connector: &dyn PeerLookup,
     message_receiver: R,
     dispatch_msg_sender: DispatchMessageSender<NetworkMessageType>,
+    pending_sender: Sender<RetryIncoming>,
 ) -> Result<(), String>
 where
     R: ConnectionMatrixReceiver + 'static,
@@ -315,12 +381,11 @@ where
                 break Err(format!("Unable to receive message: {}", context));
             }
         };
-
-        let connection_id = envelope.id();
-        let peer_id = if let Some(peer_id) = connection_id_to_peer_id.get(connection_id) {
+        let connection_id = envelope.id().to_string();
+        let peer_id = if let Some(peer_id) = connection_id_to_peer_id.get(&connection_id) {
             Some(peer_id.to_owned())
         } else if let Some(peer_id) = peer_connector
-            .peer_id(connection_id)
+            .peer_id(&connection_id)
             .map_err(|err| format!("Unable to get peer ID for {}: {}", connection_id, err))?
         {
             connection_id_to_peer_id.insert(connection_id.to_string(), peer_id.clone());
@@ -329,10 +394,11 @@ where
             None
         };
 
-        // If we have the peer, pass message to dispatcher, else print error
+        // If we have the peer, pass message to dispatcher, otherwise send message to pending
+        // thread
         if let Some(peer_id) = peer_id {
             let mut network_msg: NetworkMessage =
-                match Message::parse_from_bytes(envelope.payload()) {
+                match Message::parse_from_bytes(&envelope.payload()) {
                     Ok(msg) => msg,
                     Err(err) => {
                         error!("Unable to dispatch message: {}", err);
@@ -356,10 +422,20 @@ where
                 }
             }
         } else {
-            error!(
-                "Received message from removed or unknown peer with connection_id {}",
-                connection_id
-            );
+            match pending_sender.send(RetryIncoming::Pending(PendingIncomingMsg {
+                envelope,
+                last_attempt: Instant::now(),
+                remaining_attempts: DEFAULT_INITIAL_ATTEMPTS,
+            })) {
+                Ok(()) => debug!(
+                    "Received message from removed or unknown peer with connection_id {},\
+                             adding to pending, attempts left {}",
+                    connection_id, DEFAULT_INITIAL_ATTEMPTS
+                ),
+                Err(_) => {
+                    error!("Unable to send message to pending incoming message thread");
+                }
+            }
         }
     }
 }
@@ -428,43 +504,119 @@ where
     }
 }
 
-/// Handle for shutting down the `PeerInterconnect`.
-/// Deprecated, use ShutdownSignaler instead.
-#[derive(Clone)]
-pub struct ShutdownHandle {
-    sender: Sender<SendRequest>,
+/// Internal struct for keeping track of an pending message whose peer was not known at time of
+/// receipt.
+struct PendingIncomingMsg {
+    envelope: ConnectionMatrixEnvelope,
+    last_attempt: Instant,
+    remaining_attempts: usize,
 }
 
-impl ShutdownHandle {
-    /// Sends a shutdown notification to `PeerInterconnect` and the associated dipatcher thread
-    /// and `ConnectionMatrix`
-    pub fn shutdown(&self) {
-        if self.sender.send(SendRequest::Shutdown).is_err() {
-            warn!("Peer Interconnect is no longer running");
+/// Message for telling the pending_recv_loop, to check if messages should be retried, a new
+/// message was received whose peer is currently missing, or to shutdown.
+enum RetryIncoming {
+    Retry,
+    Pending(PendingIncomingMsg),
+    Shutdown,
+}
+
+/// This thread is in charge of retrying messages that were received but interconnect did not yet
+/// have a matching peer ID for the connection ID. It is possible this peer did not exist yet due
+/// to timing so it should be retried in the future. The message will be rechecked serveral
+/// times, but if the peer is not added after a configured number of attempts the message will
+/// be dropped. The number of pending queue messages is limited to a set size.
+fn run_pending_recv_loop(
+    peer_connector: &dyn PeerLookup,
+    receiver: Receiver<RetryIncoming>,
+    dispatch_msg_sender: DispatchMessageSender<NetworkMessageType>,
+) -> Result<(), String> {
+    let mut connection_id_to_peer_id: HashMap<String, String> = HashMap::new();
+    let mut pending_queue = VecDeque::new();
+    loop {
+        match receiver.recv() {
+            Ok(RetryIncoming::Pending(pending)) => {
+                if pending_queue.len() > DEFAULT_PENDING_QUEUE_SIZE {
+                    warn!(
+                        "PeerInterconnect pending recv queue is to large, dropping oldest message"
+                    );
+                    pending_queue.pop_front();
+                }
+                pending_queue.push_back(pending);
+                continue;
+            }
+            Ok(RetryIncoming::Retry) => (),
+            Ok(RetryIncoming::Shutdown) => {
+                info!("Received Shutdown");
+                break Ok(());
+            }
+            Err(_) => break Err("Pending retry receiver dropped".to_string()),
+        };
+
+        let mut still_need_retry = VecDeque::new();
+        for mut pending in pending_queue.into_iter() {
+            if pending.last_attempt.elapsed().as_secs() < DEFAULT_TIME_BETWEEN_ATTEMPTS {
+                still_need_retry.push_back(pending);
+                continue;
+            }
+
+            let connection_id = pending.envelope.id().to_string();
+            let peer_id = if let Some(peer_id) = connection_id_to_peer_id.get(&connection_id) {
+                Some(peer_id.to_owned())
+            } else if let Some(peer_id) = peer_connector
+                .peer_id(&connection_id)
+                .map_err(|err| format!("Unable to get peer ID for {}: {}", connection_id, err))?
+            {
+                connection_id_to_peer_id.insert(connection_id.to_string(), peer_id.clone());
+                Some(peer_id)
+            } else {
+                None
+            };
+
+            // If we have the peer, pass message to dispatcher, otherwise check if we should drop
+            // the message
+            if let Some(peer_id) = peer_id {
+                let mut network_msg: NetworkMessage =
+                    match Message::parse_from_bytes(&pending.envelope.payload()) {
+                        Ok(msg) => msg,
+                        Err(err) => {
+                            error!("Unable to dispatch message: {}", err);
+                            continue;
+                        }
+                    };
+
+                trace!(
+                    "Received message from {}: {:?}",
+                    peer_id,
+                    network_msg.get_message_type()
+                );
+                match dispatch_msg_sender.send(
+                    network_msg.get_message_type(),
+                    network_msg.take_payload(),
+                    peer_id.into(),
+                ) {
+                    Ok(()) => (),
+                    Err((message_type, _, _)) => {
+                        error!("Unable to dispatch message of type {:?}", message_type)
+                    }
+                }
+            } else if pending.remaining_attempts > 0 {
+                pending.remaining_attempts -= 1;
+                debug!(
+                    "Received message from removed or unknown peer with connection_id {},\
+                         attempts left {}",
+                    connection_id, pending.remaining_attempts
+                );
+                still_need_retry.push_back(pending);
+            } else {
+                error!(
+                    "Received message from removed or unknown peer with connection_id {},\
+                    dropping",
+                    connection_id
+                );
+            }
         }
-    }
-}
 
-impl From<ShutdownSignaler> for ShutdownHandle {
-    fn from(signaler: ShutdownSignaler) -> Self {
-        ShutdownHandle {
-            sender: signaler.sender,
-        }
-    }
-}
-
-/// Handle for shutting down the `PeerInterconnect`
-#[derive(Clone)]
-pub struct ShutdownSignaler {
-    sender: Sender<SendRequest>,
-}
-
-impl ShutdownSignaler {
-    /// Sends a shutdown message to the `PeerManager` and `Pacemaker`
-    pub fn shutdown(&self) {
-        if self.sender.send(SendRequest::Shutdown).is_err() {
-            warn!("Peer Interconnect is no longer running");
-        }
+        pending_queue = still_need_retry;
     }
 }
 
@@ -487,6 +639,7 @@ pub mod tests {
     };
     use crate::peer::{PeerManager, PeerManagerNotification};
     use crate::protos::network::NetworkEcho;
+    use crate::threading::lifecycle::ShutdownHandle;
     use crate::transport::{inproc::InprocTransport, Connection, Transport};
 
     // Verify that the PeerInterconnect properly receives messages from peers, passes them to
@@ -538,8 +691,8 @@ pub mod tests {
         let mut listener = transport
             .listen("inproc://test")
             .expect("Cannot listen for connections");
-        let mesh1 = Mesh::new(512, 128);
-        let mesh2 = Mesh::new(512, 128);
+        let mut mesh1 = Mesh::new(512, 128);
+        let mut mesh2 = Mesh::new(512, 128);
 
         // set up thread for the peer
         let (tx, rx) = mpsc::channel();
@@ -574,10 +727,11 @@ pub mod tests {
 
             rx.recv().unwrap();
 
-            mesh2.shutdown_signaler().shutdown();
+            mesh2.signal_shutdown();
+            mesh2.wait_for_shutdown().expect("Unable to shutdown mesh");
         });
 
-        let cm = ConnectionManager::builder()
+        let mut cm = ConnectionManager::builder()
             .with_authorizer(Box::new(NoopAuthorizer::new("test_peer")))
             .with_matrix_life_cycle(mesh1.get_life_cycle())
             .with_matrix_sender(mesh1.get_sender())
@@ -587,7 +741,7 @@ pub mod tests {
 
         let connector = cm.connector();
 
-        let peer_manager = PeerManager::builder()
+        let mut peer_manager = PeerManager::builder()
             .with_connector(connector)
             .with_retry_interval(1)
             .with_identity("my_id".to_string())
@@ -599,7 +753,7 @@ pub mod tests {
         let (send, recv) = channel();
 
         let (dispatcher_sender, dispatcher_receiver) = dispatch_channel();
-        let interconnect = PeerInterconnectBuilder::new()
+        let mut interconnect = PeerInterconnectBuilder::new()
             .with_peer_connector(peer_connector.clone())
             .with_message_receiver(mesh1.get_receiver())
             .with_message_sender(mesh1.get_sender())
@@ -611,15 +765,13 @@ pub mod tests {
         let handler = NetworkTestHandler::new(send);
         dispatcher.set_handler(Box::new(handler));
 
-        let network_dispatch_loop = DispatchLoopBuilder::new()
+        let mut network_dispatch_loop = DispatchLoopBuilder::new()
             .with_dispatcher(dispatcher)
             .with_thread_name("NetworkDispatchLoop".to_string())
             .with_dispatch_channel((dispatcher_sender, dispatcher_receiver))
             .build()
             .expect("Unable to create network dispatch loop");
 
-        let dispatch_shutdown = network_dispatch_loop.shutdown_signaler();
-
         let (notification_tx, notification_rx): (
             Sender<PeerManagerNotification>,
             mpsc::Receiver<PeerManagerNotification>,
@@ -654,14 +806,25 @@ pub mod tests {
         // trigger the thread shutdown
         tx.send(()).unwrap();
 
-        peer_manager.shutdown_signaler().shutdown();
-        cm.shutdown_signaler().shutdown();
-        peer_manager.await_shutdown();
-        cm.await_shutdown();
-        dispatch_shutdown.shutdown();
-        mesh1.shutdown_signaler().shutdown();
-        interconnect.shutdown_signaler().shutdown();
-        interconnect.await_shutdown();
+        peer_manager.signal_shutdown();
+        cm.signal_shutdown();
+        peer_manager
+            .wait_for_shutdown()
+            .expect("Unable to shutdown peer manager");
+        cm.wait_for_shutdown()
+            .expect("Unable to shutdown connection manager");
+        network_dispatch_loop.signal_shutdown();
+        network_dispatch_loop
+            .wait_for_shutdown()
+            .expect("Unable to shutdown connection manager");
+
+        mesh1.signal_shutdown();
+        mesh1.wait_for_shutdown().expect("Unable to shutdown mesh");
+
+        interconnect.signal_shutdown();
+        interconnect
+            .wait_for_shutdown()
+            .expect("Unable to shutdown interconnect");
     }
 
     // Verify that PeerInterconnect can be shutdown after start but without any messages being
@@ -670,9 +833,9 @@ pub mod tests {
     #[test]
     fn test_peer_interconnect_shutdown() {
         let transport = Box::new(InprocTransport::default());
-        let mesh = Mesh::new(512, 128);
+        let mut mesh = Mesh::new(512, 128);
 
-        let cm = ConnectionManager::builder()
+        let mut cm = ConnectionManager::builder()
             .with_authorizer(Box::new(NoopAuthorizer::new("test_peer")))
             .with_matrix_life_cycle(mesh.get_life_cycle())
             .with_matrix_sender(mesh.get_sender())
@@ -681,7 +844,7 @@ pub mod tests {
             .expect("Unable to start Connection Manager");
 
         let connector = cm.connector();
-        let peer_manager = PeerManager::builder()
+        let mut peer_manager = PeerManager::builder()
             .with_connector(connector)
             .with_retry_interval(1)
             .with_identity("my_id".to_string())
@@ -690,7 +853,7 @@ pub mod tests {
             .expect("Cannot start peer_manager");
         let peer_connector = peer_manager.connector();
         let (dispatcher_sender, _dispatched_receiver) = dispatch_channel();
-        let interconnect = PeerInterconnectBuilder::new()
+        let mut interconnect = PeerInterconnectBuilder::new()
             .with_peer_connector(peer_connector)
             .with_message_receiver(mesh.get_receiver())
             .with_message_sender(mesh.get_sender())
@@ -698,13 +861,21 @@ pub mod tests {
             .build()
             .expect("Unable to build PeerInterconnect");
 
-        peer_manager.shutdown_signaler().shutdown();
-        cm.shutdown_signaler().shutdown();
-        peer_manager.await_shutdown();
-        cm.await_shutdown();
-        mesh.shutdown_signaler().shutdown();
-        interconnect.shutdown_signaler().shutdown();
-        interconnect.await_shutdown();
+        peer_manager.signal_shutdown();
+        cm.signal_shutdown();
+        peer_manager
+            .wait_for_shutdown()
+            .expect("Unable to shutdown peer manager");
+        cm.wait_for_shutdown()
+            .expect("Unable to shutdown connection manager");
+
+        mesh.signal_shutdown();
+        mesh.wait_for_shutdown().expect("Unable to shutdown mesh");
+
+        interconnect.signal_shutdown();
+        interconnect
+            .wait_for_shutdown()
+            .expect("Unable to shutdown interconnect");
     }
 
     struct Shutdown {}
