@@ -73,6 +73,8 @@ pub(crate) const OAUTH_CALLBACK_MIN: u32 = 1;
 pub(crate) const OAUTH_LOGIN_MIN: u32 = 1;
 #[cfg(all(feature = "oauth", feature = "rest-api-actix"))]
 pub(crate) const OAUTH_LOGOUT_MIN: u32 = 1;
+#[cfg(all(feature = "oauth-user-list", feature = "rest-api-actix"))]
+pub(crate) const OAUTH_USER_READ_PROTOCOL_MIN: u32 = 1;
 
 #[cfg(feature = "registry")]
 pub const REGISTRY_PROTOCOL_VERSION: u32 = 1;
@@ -110,3 +112,10 @@ pub(crate) const BIOME_FETCH_PROFILE_PROTOCOL_MIN: u32 = 1;
 pub(crate) const BIOME_FETCH_PROFILES_PROTOCOL_MIN: u32 = 1;
 #[cfg(all(feature = "biome-profile", feature = "rest-api",))]
 pub(crate) const BIOME_LIST_PROFILES_PROTOCOL_MIN: u32 = 1;
+
+// Peer authorization protocol versions
+#[cfg(feature = "trust-authorization")]
+pub const PEER_AUTHORIZATION_PROTOCOL_VERSION: u32 = 1;
+
+#[cfg(feature = "trust-authorization")]
+pub(crate) const PEER_AUTHORIZATION_PROTOCOL_MIN: u32 = 1;
